@@ -12,10 +12,10 @@ pkgname=__namcap_test_infodirectory
 pkgver=1.0
 pkgrel=1
 pkgdesc="A package"
-arch=('i686' 'x86_64')
+arch=('i686' 'x86_64' 'aarch64' 'riscv64' 'loongarch64')
 url="http://www.example.com/"
-license=('GPL')
-depends=('glibc')
+license=('GPL-3.0-or-later')
+depends=('musl')
 source=()
 options=(!purge !zipman)
 build() {
